NormalizedKeyPoint

Struct NormalizedKeyPoint 

pub struct NormalizedKeyPoint(pub Point2<f64>);
A point in normalized image coordinates. This keypoint has been corrected for distortion and normalized based on the camrea intrinsic matrix. Please note that the intrinsic matrix accounts for the natural focal length and any magnification to the image. Ultimately, the key points must be represented by their position on the camera sensor and normalized to the focal length of the camera.

Tuple Fields

0: Point2<f64>

Implementations

Source

impl NormalizedKeyPoint

pub fn from_camera_point(point: CameraPoint) -> Option<Self>

Tries to convert the CameraPoint into a NormalizedKeyPoint, but it may fail in extreme conditions, in which case None is returned.

pub fn with_depth(self, depth: f64) -> CameraPoint

Conceptually appends a 1.0 component to the normalized keypoint to create a CameraPoint on the virtual image plane and then multiplies the point by depth. This z/depth component must be the depth of the keypoint in the direction the camera is pointing from the camera’s optical center.

The depth is computed as the dot product of the unit camera norm with the vector that represents the position delta of the point from the camera.

pub fn with_distance(self, distance: f64) -> CameraPoint

Projects the keypoint out to the CameraPoint that is distance away from the optical center of the camera. This distance is defined as the norm of the vector that represents the position delta of the point from the camera.

pub fn virtual_image_point(self) -> Point3<f64>

Get the virtual image point as a Point3.

The virtual image point is the point that is formed on the virtual image plane at a depth 1.0 in front of the camera.

Methods from Deref<Target = Point2<f64>>

pub fn to_homogeneous( &self, ) -> Matrix<N, <D as DimNameAdd<U1>>::Output, U1, <DefaultAllocator as Allocator<N, <D as DimNameAdd<U1>>::Output>>::Buffer>

Converts this point into a vector in homogeneous coordinates, i.e., appends a 1 at the end of it.

This is the same as .into().

Example
let p = Point2::new(10.0, 20.0);
assert_eq!(p.to_homogeneous(), Vector3::new(10.0, 20.0, 1.0));

// This works in any dimension.
let p = Point3::new(10.0, 20.0, 30.0);
assert_eq!(p.to_homogeneous(), Vector4::new(10.0, 20.0, 30.0, 1.0));
pub fn len(&self) -> usize

The dimension of this point.

Example
let p = Point2::new(1.0, 2.0);
assert_eq!(p.len(), 2);

// This works in any dimension.
let p = Point3::new(10.0, 20.0, 30.0);
assert_eq!(p.len(), 3);
pub fn stride(&self) -> usize

👎Deprecated: This methods is no longer significant and will always return 1.

The stride of this point. This is the number of buffer element separating each component of this point.

pub fn iter( &self, ) -> MatrixIter<'_, N, D, U1, <DefaultAllocator as Allocator<N, D>>::Buffer>

Iterates through this point coordinates.

Example
let p = Point3::new(1.0, 2.0, 3.0);
let mut it = p.iter().cloned();

assert_eq!(it.next(), Some(1.0));
assert_eq!(it.next(), Some(2.0));
assert_eq!(it.next(), Some(3.0));
assert_eq!(it.next(), None);
pub unsafe fn get_unchecked(&self, i: usize) -> &N

Gets a reference to i-th element of this point without bound-checking.

pub fn iter_mut( &mut self, ) -> MatrixIterMut<'_, N, D, U1, <DefaultAllocator as Allocator<N, D>>::Buffer>

Mutably iterates through this point coordinates.

Example
let mut p = Point3::new(1.0, 2.0, 3.0);

for e in p.iter_mut() {
    *e *= 10.0;
}

assert_eq!(p, Point3::new(10.0, 20.0, 30.0));
pub unsafe fn get_unchecked_mut(&mut self, i: usize) -> &mut N

Gets a mutable reference to i-th element of this point without bound-checking.

pub unsafe fn swap_unchecked(&mut self, i1: usize, i2: usize)

Swaps two entries without bound-checking.

pub fn inf(&self, other: &Point<N, D>) -> Point<N, D>

Computes the infimum (aka. componentwise min) of two points.

pub fn sup(&self, other: &Point<N, D>) -> Point<N, D>

Computes the supremum (aka. componentwise max) of two points.

pub fn inf_sup(&self, other: &Point<N, D>) -> (Point<N, D>, Point<N, D>)

Computes the (infimum, supremum) of two points.

pub fn xx(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn xxx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn xy(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn yx(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn yy(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn xxy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn xyx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn xyy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yxx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yxy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yyx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yyy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn xz(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn yz(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn zx(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn zy(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn zz(&self) -> Point<N, U2>

Builds a new point from components of self.

pub fn xxz(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn xyz(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn xzx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn xzy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn xzz(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yxz(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yyz(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yzx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yzy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn yzz(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zxx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zxy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zxz(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zyx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zyy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zyz(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zzx(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zzy(&self) -> Point<N, U3>

Builds a new point from components of self.

pub fn zzz(&self) -> Point<N, U3>

Builds a new point from components of self.